"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.MappedExceptionFilter = void 0;
const common_1 = require("@nestjs/common");
const rxjs_1 = require("rxjs");
const typeorm_1 = require("typeorm");
const mapped_exception_error_class_1 = require("../mapped-exception-error.class");
var ErrorLayerEnum;
(function (ErrorLayerEnum) {
    ErrorLayerEnum[ErrorLayerEnum["DATABASE"] = 0] = "DATABASE";
    ErrorLayerEnum[ErrorLayerEnum["VALIDATION"] = 1] = "VALIDATION";
    ErrorLayerEnum[ErrorLayerEnum["APPLICATION"] = 2] = "APPLICATION";
    ErrorLayerEnum[ErrorLayerEnum["EXCEPTION"] = 3] = "EXCEPTION";
})(ErrorLayerEnum || (ErrorLayerEnum = {}));
let MappedExceptionFilter = (() => {
    let MappedExceptionFilter = class MappedExceptionFilter {
        constructor() {
            this.defaultApplicationErrorPrefix = process.env.EXCEPTION_ERROR_PREFIX || 'APPLICATION_ERR';
            this.defaultDatabaseErrorPrefix = process.env.EXCEPTION_DATABASE_ERROR_PREFIX || 'DATABASE_ERR';
            this.defaultValidationErrorPrefix = process.env.EXCEPTION_VALIDATION_ERROR_PREFIX || 'VALIDATION_ERR';
        }
        catch(exception, host) {
            const ctx = host.switchToHttp();
            const response = ctx.getResponse();
            const request = ctx.getRequest();
            const { status = common_1.HttpStatus.INTERNAL_SERVER_ERROR, message, code, } = this.getStatusAndMessage(exception);
            const contextType = host.getType();
            if (contextType === 'http') {
                return this.handleRestContext(request, response, status, message, code);
            }
            if (contextType === 'rpc') {
                return this.handleRpcContext(code, message);
            }
            if (contextType === 'graphql') {
                return this.graphqlFormatError(status, message, code);
            }
        }
        getStatusAndMessage(exception) {
            const errorLayer = this.identifyErrorLayer(exception);
            if (errorLayer === ErrorLayerEnum.DATABASE) {
                return {
                    code: this.defaultDatabaseErrorPrefix,
                    message: exception.message,
                    status: common_1.HttpStatus.INTERNAL_SERVER_ERROR,
                };
            }
            if (errorLayer === ErrorLayerEnum.VALIDATION) {
                return {
                    code: this.defaultValidationErrorPrefix,
                    message: exception.message,
                    status: common_1.HttpStatus.BAD_REQUEST,
                };
            }
            if (errorLayer === ErrorLayerEnum.EXCEPTION) {
                const { code, message, statusCode } = exception.exception;
                return {
                    code: code.toString(),
                    message,
                    status: statusCode,
                };
            }
            if (errorLayer === ErrorLayerEnum.APPLICATION) {
                if (exception instanceof common_1.HttpException) {
                    return {
                        code: this.defaultApplicationErrorPrefix,
                        message: exception.message,
                        status: exception.getStatus(),
                    };
                }
                return {
                    code: this.defaultApplicationErrorPrefix,
                    message: exception.message,
                    status: common_1.HttpStatus.INTERNAL_SERVER_ERROR,
                };
            }
        }
        handleRestContext(request, response, status, message, code) {
            return response.code(status).send({
                message,
                code,
                statusCode: status,
                timestamp: new Date().toISOString(),
                path: request.url,
            });
        }
        handleRpcContext(code, message = '') {
            return rxjs_1.throwError(new Error(`${message} [${code}]`));
        }
        graphqlFormatError(status, message, code) {
            return new common_1.HttpException({
                message,
                code,
                statusCode: status,
            }, status);
        }
        identifyErrorLayer(exception) {
            if (exception instanceof typeorm_1.QueryFailedError) {
                return ErrorLayerEnum.DATABASE;
            }
            if (exception instanceof common_1.BadRequestException) {
                return ErrorLayerEnum.VALIDATION;
            }
            if (exception instanceof mapped_exception_error_class_1.MappedExceptionError) {
                return ErrorLayerEnum.EXCEPTION;
            }
            return ErrorLayerEnum.APPLICATION;
        }
    };
    MappedExceptionFilter = __decorate([
        common_1.Catch()
    ], MappedExceptionFilter);
    return MappedExceptionFilter;
})();
exports.MappedExceptionFilter = MappedExceptionFilter;
//# sourceMappingURL=mapped-exception.filter.js.map